Name:           motion
Version:        4.1.1
Release:        1%{?dist}
Summary:        A motion detection system

Group:          Applications/Multimedia
License:        GPLv2+
URL:            https://motion-project.github.io/
Source0:        https://github.com/Motion-Project/%{name}/archive/release-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

Patch1:         motion-4.1.1-systemd.patch

BuildRequires:  libjpeg-devel zlib-devel libwebp-devel mariadb-devel postgresql-devel
#This requires comes from the startup script, it will be there until motion supports libv4l calls in the code
Requires: libv4l
Requires(post):   systemd-units
Requires(preun):  systemd-units
Requires(postun): systemd-units

%description
Motion is a software motion detector. It grabs images from video4linux devices
and/or from webcams (such as the axis network cameras). Motion is the perfect
tool for keeping an eye on your property keeping only those images that are
interesting. Motion is strictly command line driven and can run as a daemon
with a rather small footprint. This version is built without ffmpeg support
but with MySQL and PostgreSQL support.

%prep
%setup -q -n %{name}-release-%{version}

%patch1 -p1

%build
autoreconf -fiv
echo "##### %{_prefix}"
%configure \
  --exec-prefix=NONE \
  --without-optimizecpu \
  --without-ffmpeg
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
#We rename the configuration file
mv %{buildroot}%{_sysconfdir}/%{name}/motion-dist.conf %{buildroot}%{_sysconfdir}/%{name}/motion.conf
#We remove SQL directives in the configuration file, as we don't use them
sed -i 's|sql_log_image|; sql_log_image|g' %{buildroot}%{_sysconfdir}/%{name}/motion.conf
sed -i 's|sql_log_snapshot|; sql_log_snapshot|g' %{buildroot}%{_sysconfdir}/%{name}/motion.conf
sed -i 's|sql_log_mpeg|; sql_log_mpeg|g' %{buildroot}%{_sysconfdir}/%{name}/motion.conf
sed -i 's|sql_log_timelapse|; sql_log_timelapse|g' %{buildroot}%{_sysconfdir}/%{name}/motion.conf
sed -i 's|sql_query|; sql_query|g' %{buildroot}%{_sysconfdir}/%{name}/motion.conf
#We set the log file and target directory - logging is for 3.3 branch
sed -i 's|;logfile|logfile /var/log/motion.log|g' %{buildroot}%{_sysconfdir}/%{name}/motion.conf
sed -i 's|target_dir /usr/local/apache2/htdocs/cam1|target_dir /var/motion|g' %{buildroot}%{_sysconfdir}/%{name}/motion.conf
#We install our startup script
install -d -m 755 ${RPM_BUILD_ROOT}%{_unitdir}
install -m 0644 motion.service ${RPM_BUILD_ROOT}/%{_unitdir}/motion.service

%post
%systemd_post motion.service

%preun
%systemd_preun motion.service

%postun
%systemd_postun_with_restart motion.service

%clean
rm -rf %{buildroot}

%files
#Permissions are bogus upstream, we need to be sure to set them here
%defattr (-,root,root,-)
%config(noreplace) %{_sysconfdir}/%{name}/motion.conf
%config(noreplace) %{_sysconfdir}/%{name}/camera1-dist.conf
%config(noreplace) %{_sysconfdir}/%{name}/camera2-dist.conf
%config(noreplace) %{_sysconfdir}/%{name}/camera3-dist.conf
%config(noreplace) %{_sysconfdir}/%{name}/camera4-dist.conf
%config %{_unitdir}/*.service
/usr/share/doc/%{name}
%{_datadir}/%{name}
%attr(0755,root,root) %{_bindir}/motion
%attr(0644,root,root) %{_mandir}/man1/motion.1*

%changelog
* Sat Mar 06 2010 Steven Moix <steven.moix@axianet.ch> - 3.2.12-1
- New upstream release, important bugfixes only

* Wed Oct 21 2009 Thorsten Leemhuis <fedora [AT] leemhuis [DOT] info> - 3.2.11.1-3
- rebuild for new ffmpeg

* Tue Aug 11 2009 Steven Moix <steven.moix@axianet.ch> - 3.2.11.1-1
- Drop patch for ffmpeg 0.5 compatibility
- Drop ffmpeg detection patch
- Moved default output directory to /var/motion
- New startup script with added v4l2convert to support more cameras - https://bugzilla.rpmfusion.org/show_bug.cgi?id=681
- Fix Segfault on reload or quit for vloopback (maybe other v4l1 devices too)
- Fix fd leaks in external pipe
- Avoid possible stack smashing in v4l_open_vidpipe()
- Fix segfault for new libjpeg v7

* Mon Jul 06 2009 Steven Moix <steven.moix@axianet.ch> - 3.3.0-1
- SPEC Preparation for the 3.3 branch

* Fri Jun 05 2009 Steven Moix <steven.moix@axianet.ch> - 3.2.11-5
- Patch and rebuild for ffmpeg 0.5

* Sun Mar 29 2009 Thorsten Leemhuis <fedora [AT] leemhuis [DOT] info> - 3.2.11-4
- rebuild for new F11 features

* Wed Mar 18 2009 Steven Moix <steven.moix@axianet.ch> - 3.2.11-3
- Even more corrected init script thanks to Stewart Adam

* Sun Mar 15 2009 Steven Moix <steven.moix@axianet.ch> - 3.2.11-2
- Removed the ffmpeg requires
- Corrected the spec file
- New init script with a corrected start() function and LSB header support

* Tue Mar 03 2009 Steven Moix <steven.moix@axianet.ch> - 3.2.11-1
- Updated to Fedora 10 standard

* Sun Sep 18 2005 Kenneth Lavrsen <kenneth@lavrsen.dk> - 3.2.4-1
- Generic version of livna spec file replacing the old less optimal specfile.

* Thu Sep 15 2005 Dams <anvil[AT]livna.org> - 3.2.3-0.lvn.1
- Initial released based upon upstream spec file
